#[non_exhaustive]pub enum WhoIsError {
SerdeJsonError(Error),
IOError(Error),
HostError(HostError),
Elapsed(Elapsed),
MapError(&'static str),
}Expand description
The error type of this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SerdeJsonError(Error)
The server list is not valid JSON.
IOError(Error)
Reading the server list, or talking to a WHOIS server, failed.
HostError(HostError)
The target of a lookup is not a valid domain or IP.
Elapsed(Elapsed)
Available on crate feature
tokio only.An asynchronous operation did not finish before its timeout.
MapError(&'static str)
This kind of errors is recommended to be panic!