pub struct WhoIsServerValue {
pub host: WhoIsHost,
pub query: Option<String>,
pub punycode: bool,
}Expand description
The model of a WHOIS server.
Fields
host: WhoIsHostThe host of this server.
query: Option<String>The query to send, where $addr is replaced by the target. None means the default query, "$addr\r\n".
punycode: boolWhether this server wants a domain in its ASCII (Punycode) form. The default value is true.
Implementations
Sourceimpl WhoIsServerValue
impl WhoIsServerValue
Sourcepub fn from_value(value: &Value) -> Result<WhoIsServerValue, WhoIsError>
pub fn from_value(value: &Value) -> Result<WhoIsServerValue, WhoIsError>
Read a server from an entry of a server list. The entry is either a host string, or an object with a host string and optional query and punycode fields.
Sourcepub fn from_string<S: AsRef<str>>(
string: S,
) -> Result<WhoIsServerValue, WhoIsError>
pub fn from_string<S: AsRef<str>>( string: S, ) -> Result<WhoIsServerValue, WhoIsError>
Read a server from a host string, using the default query and the default punycode setting.